@@ -50,6 +50,8 @@ use FBP::Button               ();
 use FBP::CalendarCtrl         ();
 use FBP::CheckBox             ();
 use FBP::Choice               ();
+use FBP::Choicebook           ();
+use FBP::ChoicebookPage       ();
 use FBP::ComboBox             ();
 use FBP::ColourPickerCtrl     ();
 use FBP::CustomControl        ();
@@ -61,6 +63,8 @@ use FBP::FontPickerCtrl       ();
 use FBP::FormPanel            ();
 use FBP::Frame                ();
 use FBP::Gauge                ();
+use FBP::GenericDirCtrl       ();
+use FBP::Grid                 ();
 use FBP::GridBagSizer         ();
 use FBP::GridBagSizerItem     ();
 use FBP::GridSizer            ();
@@ -79,11 +83,14 @@ use FBP::NotebookPage         ();
 use FBP::Panel                ();
 use FBP::RadioBox             ();
 use FBP::RadioButton          ();
+use FBP::RichTextCtrl         ();
+use FBP::ScrollBar            ();
 use FBP::ScrolledWindow       ();
 use FBP::SearchCtrl           ();
 use FBP::SizerItem            ();
 use FBP::Slider               ();
 use FBP::Spacer               ();
+use FBP::SpinButton           ();
 use FBP::SpinCtrl             ();
 use FBP::SplitterItem         ();
 use FBP::SplitterWindow       ();
@@ -100,7 +107,7 @@ use FBP::ToolBar              ();
 use FBP::ToolSeparator        ();
 use FBP::TreeCtrl             ();
 
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 
 extends 'FBP::Object';
 with    'FBP::Children';
