@@ -7,7 +7,7 @@ use Params::Util   ();
 use XML::SAX::Base ();
 use FBP            ();
 
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 our @ISA     = 'XML::SAX::Base';
 
 # Object XML class to Perl class mapping
@@ -25,6 +25,7 @@ my %OBJECT_CLASS = (
 	wxCalendarCtrl         => 'FBP::CalendarCtrl',
 	wxCheckBox             => 'FBP::CheckBox',
 	wxChoice               => 'FBP::Choice',
+	wxChoicebook           => 'FBP::Choicebook',
 	wxComboBox             => 'FBP::ComboBox',
 	wxColourPickerCtrl     => 'FBP::ColourPickerCtrl',
 	wxDatePickerCtrl       => 'FBP::DatePickerCtrl',
@@ -33,6 +34,8 @@ my %OBJECT_CLASS = (
 	wxFlexGridSizer        => 'FBP::FlexGridSizer',
 	wxFontPickerCtrl       => 'FBP::FontPickerCtrl',
 	wxGauge                => 'FBP::Gauge',
+	wxGenericDirCtrl       => 'FBP::GenericDirCtrl',
+	wxGrid                 => 'FBP::Grid',
 	wxGridBagSizer         => 'FBP::GridBagSizer',
 	wxGridSizer            => 'FBP::GridSizer',
 	wxHtmlWindow           => 'FBP::HtmlWindow',
@@ -47,9 +50,12 @@ my %OBJECT_CLASS = (
 	wxPanel                => 'FBP::Panel',
 	wxRadioBox             => 'FBP::RadioBox',
 	wxRadioButton          => 'FBP::RadioButton',
+	wxRichTextCtrl         => 'FBP::RichTextCtrl',
+	wxScrollBar            => 'FBP::ScrollBar',
 	wxScrolledWindow       => 'FBP::ScrolledWindow',
 	wxSearchCtrl           => 'FBP::SearchCtrl',
 	wxSlider               => 'FBP::Slider',
+	wxSpinButton           => 'FBP::SpinButton',
 	wxSpinCtrl             => 'FBP::SpinCtrl',
 	wxSplitterWindow       => 'FBP::SplitterWindow',
 	wxStaticBitmap         => 'FBP::StaticBitmap',
@@ -64,6 +70,7 @@ my %OBJECT_CLASS = (
 	wxTreeCtrl             => 'FBP::TreeCtrl',
 
 	# Special Mappings
+	choicebookpage         => 'FBP::ChoicebookPage',
 	gbsizeritem            => 'FBP::GridBagSizerItem',
 	listbookpage           => 'FBP::ListbookPage',
 	notebookpage           => 'FBP::NotebookPage',
